@@ -12,18 +12,19 @@ By default account id and token expiration time are stored in extra_data
 field, check OAuthBackend class for details on how to extend it.
 """
 import cgi
-from urllib import urlencode
-from urllib2 import urlopen, HTTPError
 import base64
 import hmac
 import hashlib
 import time
+from urllib import urlencode
+from urllib2 import HTTPError
 
 from django.utils import simplejson
 from django.contrib.auth import authenticate
 
 from social_auth.backends import BaseOAuth2, OAuthBackend, USERNAME
-from social_auth.utils import sanitize_log_data, backend_setting, setting, log
+from social_auth.utils import sanitize_log_data, backend_setting, setting, \
+                              log, dsa_urlopen
 from social_auth.backends.exceptions import AuthException, AuthCanceled, \
                                             AuthFailed, AuthTokenError, \
                                             AuthUnknownError
@@ -71,7 +72,7 @@ class FacebookAuth(BaseOAuth2):
         url = FACEBOOK_ME + urlencode(params)
 
         try:
-            data = simplejson.load(urlopen(url))
+            data = simplejson.load(dsa_urlopen(url))
         except ValueError:
             extra = {'access_token': sanitize_log_data(access_token)}
             log('error', 'Could not load user data from Facebook.',
@@ -101,7 +102,7 @@ class FacebookAuth(BaseOAuth2):
                 'code': self.data['code']
             })
             try:
-                response = cgi.parse_qs(urlopen(url).read())
+                response = cgi.parse_qs(dsa_urlopen(url).read())
             except HTTPError:
                 raise AuthFailed(self, 'There was an error authenticating ' \
                                        'the app')
