@@ -1,21 +1,16 @@
 from uuid import uuid4
 
 from social_auth.utils import setting
-from social_auth.models import User
-from social_auth.backends.pipeline import USERNAME, USERNAME_MAX_LENGTH, \
-                                          warn_setting
+from social_auth.models import UserSocialAuth
+from social_auth.backends import USERNAME
+from social_auth.backends.pipeline import warn_setting
 from social_auth.signals import socialauth_not_registered, \
                                 socialauth_registered, \
                                 pre_update
 
 
-def simple_user_exists(*args, **kwargs):
-    """Return True/False if a User instance exists with the given arguments.
-    Arguments are directly passed to filter() manager method."""
-    return User.objects.filter(*args, **kwargs).exists()
-
-
-def get_username(details, user=None, user_exists=simple_user_exists,
+def get_username(details, user=None,
+                 user_exists=UserSocialAuth.simple_user_exists,
                  *args, **kwargs):
     """Return an username for new user. Return current user username
     if user was given.
@@ -42,15 +37,16 @@ def get_username(details, user=None, user_exists=simple_user_exists,
     uuid_length = setting('SOCIAL_AUTH_UUID_LENGTH', 16)
     username_fixer = setting('SOCIAL_AUTH_USERNAME_FIXER', lambda u: u)
 
-    short_username = username[:USERNAME_MAX_LENGTH - uuid_length]
-    final_username = username_fixer(username)[:USERNAME_MAX_LENGTH]
+    max_length = UserSocialAuth.username_max_length()
+    short_username = username[:max_length - uuid_length]
+    final_username = username_fixer(username)[:max_length]
 
     # Generate a unique username for current user using username
     # as base but adding a unique hash at the end. Original
     # username is cut to avoid any field max_length.
     while user_exists(username=final_username):
         username = short_username + uuid4().get_hex()[:uuid_length]
-        final_username = username_fixer(username)[:USERNAME_MAX_LENGTH]
+        final_username = username_fixer(username)[:max_length]
 
     return {'username': final_username}
 
@@ -73,9 +69,9 @@ def create_user(backend, details, response, uid, username, user=None, *args,
                                        details=details)
         return None
 
-    email = details.get('email')
+    email = details.get('email') or None
     return {
-        'user': User.objects.create_user(username=username, email=email),
+        'user': UserSocialAuth.create_user(username=username, email=email),
         'is_new': True
     }
 
@@ -91,7 +87,9 @@ def update_user_details(backend, details, response, user, is_new=False, *args,
     if not setting('SOCIAL_AUTH_CHANGE_SIGNAL_ONLY'):
         for name, value in details.iteritems():
             # do not update username, it was already generated
-            if name in (USERNAME, 'id', 'pk'):
+            # do not update configured fields if user already existed
+            if name in (USERNAME, 'id', 'pk') or (not is_new and
+                name in setting('SOCIAL_AUTH_PROTECTED_USER_FIELDS', [])):
                 continue
             if value and value != getattr(user, name, None):
                 setattr(user, name, value)
