@@ -3,6 +3,7 @@ import random
 import hashlib
 import urlparse
 import urllib
+from urllib2 import urlopen
 import logging
 
 from collections import defaultdict
@@ -68,6 +69,12 @@ except ImportError:  # django < 1.4
         return result == 0
 
 
+try:
+    from django.utils.functional import empty
+except ImportError:  # django < 1.4
+    empty = None
+
+
 get_random_string = random_string
 constant_time_compare = ct_compare
 utc = django_utc
@@ -230,16 +237,26 @@ def url_add_parameters(url, params):
 class LazyDict(SimpleLazyObject):
     """Lazy dict initialization."""
     def __getitem__(self, name):
-        if self._wrapped is None:
+        if self._wrapped is empty:
             self._setup()
         return self._wrapped[name]
 
     def __setitem__(self, name, value):
-        if self._wrapped is None:
+        if self._wrapped is empty:
             self._setup()
         self._wrapped[name] = value
 
 
+def dsa_urlopen(*args, **kwargs):
+    """Like urllib2.urlopen but sets a timeout defined by
+    SOCIAL_AUTH_URLOPEN_TIMEOUT setting if defined (and not already in
+    kwargs)."""
+    timeout = setting('SOCIAL_AUTH_URLOPEN_TIMEOUT')
+    if timeout and 'timeout' not in kwargs:
+        kwargs['timeout'] = timeout
+    return urlopen(*args, **kwargs)
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
